
import { motion } from 'framer-motion';
import { ReactNode } from 'react';

type SlideProps = {
  children: ReactNode
  index: number
  currentSlide: number
}

export default function Slide({ children, index, currentSlide }: SlideProps) {
  const isActive = index === currentSlide

  return (
    <motion.div
      className={`absolute top-0 left-0 w-full h-full flex flex-col items-center justify-center text-center gap-4 text-4xl`}
      initial={{ opacity: 0 }} // Start off-screen
      // x to left-100% for previous slides, 0 for current, and right-100% for next slides
      animate={{ x: isActive ? 0 : index < currentSlide ? '-100%' : '100%', opacity: isActive ? 1 : 0 }}
      transition={{ duration: 0.8 }}
    >
      {children}
    </motion.div>
  )
}
